powered by
Transform a distance matrix to a 3-column matrix in which the first 2 columns indicate the pairwised samples/species names.
dist.3col(dist)
1st column, the first item of pairwised two items
2nd column, the second item of pairwised two items
3rd column, distance value of the pairwised two itmes
a square matrix or distance object with column names and row names.
Daliang Ning
In many cases, a 3-column matrix is easier to use than a distance matrix.
# In this example, dist.3col transforms the distance object # of Bray-Curtis dissimilarity to 3-column matrix. data("example.data") comm=example.data$comm BC=vegan::vegdist(comm) BC3c=dist.3col(BC)
Run the code above in your browser using DataLab