# NOT RUN {
data("example.data")
comm=example.data$comm
tree=example.data$tree
# since need to save some outputs to a certain folder,
# the following code is set as 'not test'.
# but you may test the code on your computer
# after change the path for 'save.wd'.
# }
# NOT RUN {
save.wd=tempdir() # please change to the folder you want to save the pd.big output.
pd.wd=paste0(save.wd,"/pdbig")
nworker=4 # parallel computing thread number
rand.time=20 # usually use 1000 for real data.
bin.size.limit=5 # for real data, usually use a proper number
# according to phylogenetic signal test or try some settings
# then choose the reasonable stochasticity level.
# our experience is 12, or 24, or 48.
# but for this example dataset which is too small, have to use 5.
setwd(save.wd)
icamp.out=icamp.big(comm=comm,tree=tree,pd.wd=pd.wd,
rand=rand.time, nworker=nworker,
bin.size.limit=bin.size.limit)
# }
Run the code above in your browser using DataLab