- name.check
A character vector, indicating reference name list or the names you would like to keep. If not available, a union of all names is set as reference name list.
- rn.list
A list object, including the matrix(es) of which the row names will be check. rn.list must be set in a format like "rn.list=list(A=A,B=B)". default is nothing.
- cn.list
A list object, including the matrix(es) of which the column names will be check. cn.list must be set in a format like "cn.list=list(A=A,B=B)". default is nothing.
- both.list
A list object, including the matrix(es) of which both column and row names will be check. both.list must be set in a format like "both.list=list(A=A,B=B)". default is nothing.
- v.list
A list object, including the vector(s) of which the names will be check. v.list must be set in a format like "v.list=list(A=A,B=B)".default is nothing.
- lf.list
A list object, including the list(s) of which the names will be check. lf.list must be set in a format like "lf.list=list(A=A,B=B)".default is nothing.
- tree.list
A list object, including the tree(s) of which the tip.label names will be check. tree.list must be set in a format like "tree.list=list(A=A,B=B)".default is nothing.
- group
a vector or one-column matrix/data.frame indicating the grouping information of samples or species, of which the sample/species names will be check.
- rerank
Logic, make all names in the same rank or not. Default is TRUE
- silent
Logic, whether to show messages. Default is FALSE, thus all messages will be showed.