Learn R Programming

iCAMP (version 1.8.6)

mntdn: Mean nearest taxon distance (MNTD)

Description

Calculate mean nearest taxon distance (MNTD) in each community in a given community matrix.

Usage

mntdn(comm, pd, abundance.weighted = TRUE,
      check.name = TRUE, memory.G = 50, time.count = FALSE)

Value

result is a numeric vector with sample names

Arguments

comm

matrix or data.frame, community data matrix, rownames are sample names, colnames are OTU ids.

pd

matrix, pairwise phylogenetic distance matrix.

abundance.weighted

logic, whether weighted by species abundance, default is TRUE, means weighted.

check.name

logic, whether to check the OTU ids (species names) in community matrix and phylogenetic distance matrix are the same.

memory.G

numeric, to set the memory size as you need, so that calculation of large tree will not be limited by physical memory. unit is Gb. default is 50Gb

time.count

logic, whether to count calculation time, default is FALSE.

Author

Daliang Ning

Details

mean nearest taxon distance (MNTD) in each community, using the same algrithm as the function 'mntd' in package 'picante'.

References

Webb CO, Ackerly DD, and Kembel SW. (2008). Phylocom: software for the analysis of phylogenetic community structure and trait evolution. Bioinformatics 18:2098-2100

Kembel, S.W., Cowan, P.D., Helmus, M.R., Cornwell, W.K., Morlon, H., Ackerly, D.D. et al. (2010). Picante: R tools for integrating phylogenies and ecology. Bioinformatics, 26, 1463-1464.

See Also

NTI.p

Examples

Run this code
data("example.data")
comm=example.data$comm
pd=example.data$pd
mntd=mntdn(comm=comm,pd=pd,abundance.weighted = TRUE)

Run the code above in your browser using DataLab