- tree
phylogenetic tree, an object of class "phylo".
- wd
path of a folder to save the big phylogenetic distance matrix, default is current work directory.
- tree.asbig
logic, whether to treat tree attributes also as big data, default is FALSE, generally no need to set as TRUE.
- output
logic, whether to output the big phylogenetic distance matrix, default is FALSE, generally do not output it, could be too large.
- nworker
for parallel computing the tree paths. a positive integer (in which case that number of copies is run on localhost). default is 4, means 4 threads will be run.
- nworker.pd
for parallel computing the phylogenetic distance matrix. default is set the same as nworker. may need to set lower than nworker if the matrix is too large.
- memory.G
numeric, to set the memory size as you need, so that calculation of large tree will not be limited by physical memory. unit is Gb. default is 50Gb
- time.count
logic, whether to count calculation time, default is FALSE.
- treepath.file
character, name of the file saving the tree.path, which is a list of all the nodes and edge lengthes from root to every tip and/or node. it should be a .rda filename.
- pd.spname.file
character, name of the file saving the taxa IDs, which has exactly the same order as the row names (and column names) of the big phylogenetic distance matrix. it should be a .csv filename.
- pd.backingfile
character, the root name for the file for the cache of the big phylogenetic distance matrix. it should be a .bin filename.
- pd.desc.file
character, name of the file to hold the backingfile description for the big phylogenetic distance matrix. it should be a .desc filename.
- tree.backingfile
character, the root name for the file for the cache of the 3-column matrix of the tree information, including edge and edge length. it should be a .bin filename.
- tree.desc.file
character, name of the file to hold the backingfile description for the tree information matrix. it should be a .desc filename.