- x.desc
character, the name to describe bigmemory file of the distance matrix X, which defines values on the x-axis of correlogram. For phylogenetic signal test, this is the phylogenetic distance matrix file name, e.g., "pd.desc".
- x.name
vector, the rownames of the distance matrix X. For phylogenetic signal test, these are species name or taxa IDs.
- x.wd
the path of the folder saving the distance matrix X. For phylogenetic signal test, this is the folder saving phylogenetic distance matrix file.
- y.desc
character, the name to describe bigmemory file of the distance matrix Y. For phylogenetic signal test, this is the niche preference difference matrix file name, e.g., "pH.desc".
- y.name
vector, the rownames of the distance matrix Y. For phylogenetic signal test, these are species name or taxa IDs.
- y.wd
the path of the folder saving the distance matrix Y. For phylogenetic signal test, this is the folder saving niche difference matrix file.
- nworker
for parallel computing. Either a character vector of host names on which to run the worker copies of R, or a positive integer (in which case that number of copies is run on localhost). default is 4, means 4 threads will be run.
- interval
the interval of distance X. If break.pts is NULL, this defines how to seperate the data into different classes.
- break.pts
Vector containing the break points of the distance X distribution. Provide (n.class+1) breakpoints, that is, a list with a beginning and an ending point. Default: break.pts=NULL.
- permutations
Number of permutations for the tests of significance. Default: nperm=999. For large data files, permutation tests are rather slow.
- strata
An integer vector or factor specifying the strata for permutation. If supplied, observations are permuted only within the specified strata.
- diag.in
logic, whether count in the diagonal elements when calculating r. default is FALSE.
- temp.wd
path of a folder that temporarily stores the big matrix file for intermediate results.
- stepw
step width. When processing a large dataset, need to divid the long vector to different steps to avoid exceed size or space limitation.
- padjust.method
P value correction method, a character string. options include "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none". see function p.adjust. default is 'fdr'.
- cleanup
logic, if TRUE, it will try to remove the big matrix file for intermediate results.
- parallelset
logic, if TRUE, it will use parallel computing in the first step to set up values.